function [S,offset] = phext_t2(S,offset,k)

% Decode different NEMO profile header extensions type 2 (mission
% configuration)
%
%

% Optimare Sensorsysteme, 24.05.2012 M.Busack

switch (S.DS1_FORMAT(k))
    
    case 1
        % Format 1 vom 8-Mar-2012
        S.SERIAL = S.uD(offset+1)*256 + S.uD(offset);
        S.AIRPUMPTIME = S.uD(offset+3)*256 + S.uD(offset+2);
        S.STARTUPTIME = (S.uD(offset+5)*256 + S.uD(offset+4))/60;
        S.TIME_CYCLE = S.uD(offset+7)*256 + S.uD(offset+6);
        S.PRES_PROFILE = NaN; %orginal double
        S.PISTON_MIN = S.uD(offset+13)*256 + S.uD(offset+12);
        S.PISTON_MAX = S.uD(offset+15)*256 + S.uD(offset+14);
        S.STARTUPDELAY = S.uD(offset+17)*256 + S.uD(offset+16);
        S.DESCENT_MODE = S.uD(offset+18);
        % Byte 19 not used
        S.SPEED_DESCENT = NaN; %orginal double
        S.DESCENT_TIMEOUTFACTOR = NaN;  %orginal double
        S.DESCENT_PISTONINTERVAL_MIN = S.uD(offset+28);
        S.DESCENT_DEPTH_CONTROL = S.uD(offset+29);
        S.DESCENT_PISTONINTERVAL = S.uD(offset+31)*256 + S.uD(offset+30);
        S.DESCENT_PISTON_ONTIME = S.uD(offset+32);
        % Byte 33 not used
        S.PRES_DESCENT_MARGIN = NaN; %orginal double
        S.PRES_PARKING = NaN;   %orginal double
        S.PRES_PARKING_HYSTERESE = S.uD(offset+42);
        % Byte 43 not used
        S.ATTENUATION_FACTOR = NaN; %orginal double
        S.TIME_PARKSAMPLE = (S.uD(offset+51)*16777216 + S.uD(offset+50)*65536 + S.uD(offset+49)*256 + S.uD(offset+48))/60;
        S.PARKING_SAMPLES = S.uD(offset+52);
        S.PARKING_DELAY = S.uD(offset+53);
        S.PRES_PARKINGHIGH = S.uD(offset+55)*256 + S.uD(offset+54);
        S.SAFETYZONE_MARGIN = S.uD(offset+57)*256 + S.uD(offset+56);
        S.SAFETYZONE_COUNTCHANGE = S.uD(offset+59)*256 + S.uD(offset+58);
        S.SAFETYZONE_INCREMENT = S.uD(offset+61)*256 + S.uD(offset+60);
        S.INITIAL_PARKCOUNT = S.uD(offset+63)*256 + S.uD(offset+62);
        S.SPEED_SAG = NaN;  %orginal double
        S.SAG_TIMEOUTFACTOR = NaN;  %orginal double
        S.ASCENT_MODE = S.uD(offset+72);
        % Byte 73 not used
        S.SPEED_ASCENT = NaN;   %orginal double
        S.ASCENT_TIMEOUTFACTOR = NaN;  %orginal double
        S.ASCENT_PISTONINTERVAL_MIN = S.uD(offset+82);
        S.ASCENT_DEPTH_CONTROL = S.uD(offset+83);
        S.ASCENT_PISTONINTERVAL = S.uD(offset+85)*256 + S.uD(offset+84);
        S.ASCENT_PISTON_ONTIME = S.uD(offset+86);
        % Byte 87 not used
        S.TEMP_ICEDETECT = NaN; %orginal double
        S.PRES_ICEUP = S.uD(offset+93)*256 + S.uD(offset+92);   %until here verified with sbd 1
        S.PRES_ICEDOWN = S.uD(offset+95)*256 + S.uD(offset+94);
        S.PRES_ICEINTERVAL = S.uD(offset+96);
        S.SUCCESSFUL_ASCENTS = S.uD(offset+97);
        S.POST_UPCAST_SAMPLES = S.uD(offset+98);
        S.POST_UPCAST_DELAY = S.uD(offset+99);
        S.TIME_SURFACE_ATTEMP = S.uD(offset+100);
        % Byte 101 not used
        S.TIME_TX = (S.uD(offset+105)*16777216 + S.uD(offset+104)*65536 + S.uD(offset+103)*256 + S.uD(offset+102))/60;
        S.MULTIMSG = [S.uD(offset+106) S.uD(offset+107) S.uD(offset+108) S.uD(offset+109)];
        S.ARGOSID = S.uD(offset+110);
        S.RAFOS_MODULEADR = S.uD(offset+111);
        S.RECOVERY_START = S.uD(offset+113)*256 + S.uD(offset+112);
        S.RECOVERY_TX = S.uD(offset+114);
        % Byte 115 not used
        S.RECOVERY_NOTX = S.uD(offset+117)*256 + S.uD(offset+116);
        S.LOGMODE = S.uD(offset+118);
        S.TESTMODE = S.uD(offset+119);
        S.TIME_CO2WARMUP = (S.uD(offset+121)*256 + S.uD(offset+120))/60;
        S.TIME_GPSFIX = (S.uD(offset+123)*256 + S.uD(offset+122))/60;
        S.PRES_MAXALARM = S.uD(offset+125)*256 + S.uD(offset+124);
        S.COUNT_MAXALARM = S.uD(offset+127)*256 + S.uD(offset+126);
        S.CTDCP_FILTER = S.uD(offset+129)*256 + S.uD(offset+128);
        S.PRES_CTDOFF_MAX = (S.sD(offset+131)*256 + S.uD(offset+130))/10;
        S.PRES_CTDOFF_MIN = (S.sD(offset+133)*256 + S.uD(offset+132))/10;
        S.PRES_CTDOFF_CHN = (S.uD(offset+135)*256 + S.uD(offset+134))/10;
        S.PRES_PCUTOFF = (S.uD(offset+137)*256 + S.uD(offset+136))/10;
        S.PRES_SAFETY = NaN;    %orginal double
        S.STARTPROFILE = S.uD(offset+143)*256 + S.uD(offset+142);
        S.ICEGPS_TIMEOUT = S.uD(offset+144);
        S.ICEIRDM_TIMEOUT = S.uD(offset+145);
        S.CONFIGTX = S.uD(offset+146);
        S.RAFOS_ACTIVE = [S.uD(offset+147) S.uD(offset+148) S.uD(offset+149) S.uD(offset+150) S.uD(offset+151)];
        S.RAFOS_STARTHH = [S.uD(offset+152) S.uD(offset+153) S.uD(offset+154) S.uD(offset+155) S.uD(offset+156)];
        S.RAFOS_STARTMM = [S.uD(offset+157) S.uD(offset+158) S.uD(offset+159) S.uD(offset+160) S.uD(offset+161)];
        S.RAFOS_ONMM = [S.uD(offset+163)*256+S.uD(offset+162) S.uD(offset+165)*256+S.uD(offset+164) ...
                        S.uD(offset+167)*256+S.uD(offset+166) S.uD(offset+169)*256+S.uD(offset+168) ...
                        S.uD(offset+171)*256+S.uD(offset+170)];
        offset = offset + 172;
        
    case 2
        % Format 2 vom 23-May-2012 
        S.SERIAL = S.uD(offset+1)*256 + S.uD(offset);
        S.AIRPUMPTIME = S.uD(offset+3)*256 + S.uD(offset+2);
        S.STARTUPTIME = (S.uD(offset+5)*256 + S.uD(offset+4))/60;
        S.TIME_CYCLE = S.uD(offset+7)*256 + S.uD(offset+6);
        S.PRES_PROFILE = NaN; %orginal double
        S.PISTON_MIN = S.uD(offset+13)*256 + S.uD(offset+12);
        S.PISTON_MAX = S.uD(offset+15)*256 + S.uD(offset+14);
        S.STARTUPDELAY = S.uD(offset+17)*256 + S.uD(offset+16);
        S.DESCENT_MODE = S.uD(offset+18);
        % Byte 19 not used
        S.SPEED_DESCENT = NaN; %orginal double
        S.DESCENT_TIMEOUTFACTOR = NaN;  %orginal double
        S.DESCENT_PISTONINTERVAL_MIN = S.uD(offset+28);
        S.DESCENT_DEPTH_CONTROL = S.uD(offset+29);
        S.DESCENT_PISTONINTERVAL = S.uD(offset+31)*256 + S.uD(offset+30);
        S.DESCENT_PISTON_ONTIME = S.uD(offset+32);
        % Byte 33 not used
        S.PRES_DESCENT_MARGIN = NaN; %orginal double
        S.PRES_PARKING = NaN;   %orginal double
        S.PRES_PARKING_HYSTERESE = S.uD(offset+42);
        % Byte 43 not used
        S.ATTENUATION_FACTOR = NaN; %orginal double
        S.TIME_PARKSAMPLE = (S.uD(offset+51)*16777216 + S.uD(offset+50)*65536 + S.uD(offset+49)*256 + S.uD(offset+48))/60;
        S.PARKING_SAMPLES = S.uD(offset+52);
        S.PARKING_DELAY = S.uD(offset+53);
        S.PRES_PARKINGHIGH = S.uD(offset+55)*256 + S.uD(offset+54);
        S.SAFETYZONE_MARGIN = S.uD(offset+57)*256 + S.uD(offset+56);
        S.SAFETYZONE_COUNTCHANGE = S.uD(offset+59)*256 + S.uD(offset+58);
        S.SAFETYZONE_INCREMENT = S.uD(offset+61)*256 + S.uD(offset+60);
        S.INITIAL_PARKCOUNT = S.uD(offset+63)*256 + S.uD(offset+62);
        S.SPEED_SAG = NaN;  %orginal double
        S.SAG_TIMEOUTFACTOR = NaN;  %orginal double
        S.ASCENT_MODE = S.uD(offset+72);
        % Byte 73 not used
        S.SPEED_ASCENT = NaN;   %orginal double
        S.ASCENT_TIMEOUTFACTOR = NaN;  %orginal double
        S.ASCENT_PISTONINTERVAL_MIN = S.uD(offset+82);
        S.ASCENT_DEPTH_CONTROL = S.uD(offset+83);
        S.ASCENT_PISTONINTERVAL = S.uD(offset+85)*256 + S.uD(offset+84);
        S.ASCENT_PISTON_ONTIME = S.uD(offset+86);
        % Byte 87 not used
        S.TEMP_ICEDETECT = NaN; %orginal double
        S.PRES_ICEUP = S.uD(offset+93)*256 + S.uD(offset+92);   %until here verified with sbd 1
        S.PRES_ICEDOWN = S.uD(offset+95)*256 + S.uD(offset+94);
        S.PRES_ICEINTERVAL = S.uD(offset+96);
        S.SUCCESSFUL_ASCENTS = S.uD(offset+97);
        S.POST_UPCAST_SAMPLES = S.uD(offset+98);
        S.POST_UPCAST_DELAY = S.uD(offset+99);
        S.TIME_SURFACE_ATTEMP = S.uD(offset+100);
        % Byte 101 not used
        S.TIME_TX = (S.uD(offset+105)*16777216 + S.uD(offset+104)*65536 + S.uD(offset+103)*256 + S.uD(offset+102))/60;
        S.MULTIMSG = [S.uD(offset+106) S.uD(offset+107) S.uD(offset+108) S.uD(offset+109)];
        S.ARGOSID = S.uD(offset+110);
        S.RAFOS_MODULEADR = S.uD(offset+111);
        S.RECOVERY_START = S.uD(offset+113)*256 + S.uD(offset+112);
        S.RECOVERY_TX = S.uD(offset+114);
        % Byte 115 not used
        S.RECOVERY_NOTX = S.uD(offset+117)*256 + S.uD(offset+116);
        S.LOGMODE = S.uD(offset+118);
        S.TESTMODE = S.uD(offset+119);
        S.TIME_CO2WARMUP = (S.uD(offset+121)*256 + S.uD(offset+120))/60;
        S.TIME_GPSFIX = (S.uD(offset+123)*256 + S.uD(offset+122))/60;
        S.PRES_MAXALARM = S.uD(offset+125)*256 + S.uD(offset+124);
        S.COUNT_MAXALARM = S.uD(offset+127)*256 + S.uD(offset+126);
        S.CTDCP_FILTER = S.uD(offset+129)*256 + S.uD(offset+128);
        S.PRES_CTDOFF_MAX = (S.sD(offset+131)*256 + S.uD(offset+130))/10;
        S.PRES_CTDOFF_MIN = (S.sD(offset+133)*256 + S.uD(offset+132))/10;
        S.PRES_CTDOFF_CHN = (S.uD(offset+135)*256 + S.uD(offset+134))/10;
        S.PRES_PCUTOFF = (S.uD(offset+137)*256 + S.uD(offset+136))/10;
        S.PRES_SAFETY = NaN;    %orginal double
        S.STARTPROFILE = S.uD(offset+143)*256 + S.uD(offset+142);
        S.ICEGPS_TIMEOUT = S.uD(offset+144);
        S.ICEIRDM_TIMEOUT = S.uD(offset+145);
        S.CONFIGTX = S.uD(offset+146);
        % New 
        S.AIRPUMP_MODE = S.uD(offset+147);
        S.AIRPUMP_PRESSDIFF = S.uD(offset+149)*256 + S.uD(offset+148);
        S.AIRPUMP_TIMEOUT = S.uD(offset+151)*256 + S.uD(offset+150);
        S.MISSION_MOD = S.uD(offset+153)*256 + S.uD(offset+152);
        S.TIME_CYCLE2 = S.uD(offset+155)*256 + S.uD(offset+154);
        % Changed
        S.RAFOS_ACTIVE = [S.uD(offset+156) S.uD(offset+157) S.uD(offset+158) S.uD(offset+159) S.uD(offset+160)];
        S.RAFOS_STARTHH = [S.uD(offset+161) S.uD(offset+162) S.uD(offset+163) S.uD(offset+164) S.uD(offset+165)];
        S.RAFOS_STARTMM = [S.uD(offset+166) S.uD(offset+167) S.uD(offset+168) S.uD(offset+169) S.uD(offset+170)];
        % Byte 171 not used
        S.RAFOS_ONMM = [S.uD(offset+173)*256+S.uD(offset+172) S.uD(offset+175)*256+S.uD(offset+174) ...
                        S.uD(offset+177)*256+S.uD(offset+176) S.uD(offset+179)*256+S.uD(offset+178) ...
                        S.uD(offset+181)*256+S.uD(offset+180)];
        offset = offset + 182;
       
    case 3
        % Format 3 vom 12-June-2012 (Ice detection temperature A01 change) 
        S.SERIAL = S.uD(offset+1)*256 + S.uD(offset);
        S.AIRPUMPTIME = S.uD(offset+3)*256 + S.uD(offset+2);
        S.STARTUPTIME = (S.uD(offset+5)*256 + S.uD(offset+4))/60;
        S.TIME_CYCLE = S.uD(offset+7)*256 + S.uD(offset+6);
        S.PRES_PROFILE = NaN; %orginal double
        S.PISTON_MIN = S.uD(offset+13)*256 + S.uD(offset+12);
        S.PISTON_MAX = S.uD(offset+15)*256 + S.uD(offset+14);
        S.STARTUPDELAY = S.uD(offset+17)*256 + S.uD(offset+16);
        S.DESCENT_MODE = S.uD(offset+18);
        % Byte 19 not used
        S.SPEED_DESCENT = NaN; %orginal double
        S.DESCENT_TIMEOUTFACTOR = NaN;  %orginal double
        S.DESCENT_PISTONINTERVAL_MIN = S.uD(offset+28);
        S.DESCENT_DEPTH_CONTROL = S.uD(offset+29);
        S.DESCENT_PISTONINTERVAL = S.uD(offset+31)*256 + S.uD(offset+30);
        S.DESCENT_PISTON_ONTIME = S.uD(offset+32);
        % Byte 33 not used
        S.PRES_DESCENT_MARGIN = NaN; %orginal double
        S.PRES_PARKING = NaN;   %orginal double
        S.PRES_PARKING_HYSTERESE = S.uD(offset+42);
        % Byte 43 not used
        S.ATTENUATION_FACTOR = NaN; %orginal double
        S.TIME_PARKSAMPLE = (S.uD(offset+51)*16777216 + S.uD(offset+50)*65536 + S.uD(offset+49)*256 + S.uD(offset+48))/60;
        S.PARKING_SAMPLES = S.uD(offset+52);
        S.PARKING_DELAY = S.uD(offset+53);
        S.PRES_PARKINGHIGH = S.uD(offset+55)*256 + S.uD(offset+54);
        S.SAFETYZONE_MARGIN = S.uD(offset+57)*256 + S.uD(offset+56);
        S.SAFETYZONE_COUNTCHANGE = S.uD(offset+59)*256 + S.uD(offset+58);
        S.SAFETYZONE_INCREMENT = S.uD(offset+61)*256 + S.uD(offset+60);
        S.INITIAL_PARKCOUNT = S.uD(offset+63)*256 + S.uD(offset+62);
        S.SPEED_SAG = NaN;  %orginal double
        S.SAG_TIMEOUTFACTOR = NaN;  %orginal double
        S.ASCENT_MODE = S.uD(offset+72);
        % Byte 73 not used
        S.SPEED_ASCENT = NaN;   %orginal double
        S.ASCENT_TIMEOUTFACTOR = NaN;  %orginal double
        S.ASCENT_PISTONINTERVAL_MIN = S.uD(offset+82);
        S.ASCENT_DEPTH_CONTROL = S.uD(offset+83);
        S.ASCENT_PISTONINTERVAL = S.uD(offset+85)*256 + S.uD(offset+84);
        S.ASCENT_PISTON_ONTIME = S.uD(offset+86);
        % Byte 87 not used
        S.TEMP_ICEDETECT = NaN; %orginal double
        S.ICE_DTMEDIAN = S.uD(offset+92);
        S.ICE_DTENTRY = S.uD(offset+93);
        S.SUCCESSFUL_ASCENTS = S.uD(offset+94);
        S.POST_UPCAST_SAMPLES = S.uD(offset+95);
        S.POST_UPCAST_DELAY = S.uD(offset+96);
        S.TIME_SURFACE_ATTEMP = S.uD(offset+97);
        S.TIME_TX = (S.uD(offset+101)*16777216 + S.uD(offset+100)*65536 + S.uD(offset+99)*256 + S.uD(offset+98))/60;
        S.MULTIMSG = [S.uD(offset+102) S.uD(offset+103) S.uD(offset+104) S.uD(offset+105)];
        S.ARGOSID = S.uD(offset+106);
        S.RAFOS_MODULEADR = S.uD(offset+107);
        S.RECOVERY_START = S.uD(offset+109)*256 + S.uD(offset+108);
        S.RECOVERY_TX = S.uD(offset+110);
        % Byte 111 not used
        S.RECOVERY_NOTX = S.uD(offset+113)*256 + S.uD(offset+112);
        S.LOGMODE = S.uD(offset+114);
        S.TESTMODE = S.uD(offset+115);
        S.TIME_CO2WARMUP = (S.uD(offset+117)*256 + S.uD(offset+116))/60;
        S.TIME_GPSFIX = (S.uD(offset+119)*256 + S.uD(offset+118))/60;
        S.PRES_MAXALARM = S.uD(offset+121)*256 + S.uD(offset+120);
        S.COUNT_MAXALARM = S.uD(offset+123)*256 + S.uD(offset+122);
        S.CTDCP_FILTER = S.uD(offset+125)*256 + S.uD(offset+124);
        S.PRES_CTDOFF_MAX = (S.sD(offset+127)*256 + S.uD(offset+126))/10;
        S.PRES_CTDOFF_MIN = (S.sD(offset+129)*256 + S.uD(offset+128))/10;
        S.PRES_CTDOFF_CHN = (S.uD(offset+131)*256 + S.uD(offset+130))/10;
        S.PRES_PCUTOFF = (S.uD(offset+133)*256 + S.uD(offset+132))/10;
        S.PRES_SAFETY = NaN;    %orginal double
        S.STARTPROFILE = S.uD(offset+139)*256 + S.uD(offset+138);
        S.ICEGPS_TIMEOUT = S.uD(offset+140);
        S.ICEIRDM_TIMEOUT = S.uD(offset+141);
        S.CONFIGTX = S.uD(offset+142);
        S.AIRPUMP_MODE = S.uD(offset+143);
        S.AIRPUMP_PRESSDIFF = S.uD(offset+145)*256 + S.uD(offset+144);
        S.AIRPUMP_TIMEOUT = S.uD(offset+147)*256 + S.uD(offset+146);
        S.MISSION_MOD = S.uD(offset+149)*256 + S.uD(offset+148);
        S.TIME_CYCLE2 = S.uD(offset+151)*256 + S.uD(offset+150);
        % Changed
        S.RAFOS_ACTIVE = [S.uD(offset+152) S.uD(offset+153) S.uD(offset+154) S.uD(offset+155) S.uD(offset+156)];
        S.RAFOS_STARTHH = [S.uD(offset+157) S.uD(offset+158) S.uD(offset+159) S.uD(offset+160) S.uD(offset+161)];
        S.RAFOS_STARTMM = [S.uD(offset+162) S.uD(offset+163) S.uD(offset+164) S.uD(offset+165) S.uD(offset+166)];
        % Byte 167 not used
        S.RAFOS_ONMM = [S.uD(offset+169)*256+S.uD(offset+168) S.uD(offset+171)*256+S.uD(offset+170) ...
                        S.uD(offset+173)*256+S.uD(offset+172) S.uD(offset+175)*256+S.uD(offset+174) ...
                        S.uD(offset+177)*256+S.uD(offset+176)];
        offset = offset + 178;
    otherwise
        % Do nothing
        
end

% function end
end


    